@@ -150,6 +150,37 @@ sub execute {
     }
 
 
+    ######################
+    use DateTime;
+    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
+    $year += 1900;
+    $mon += 1;
+    my $now_date = sprintf "%04d-%02d-%02d %02d:%02d:%02d", $year, $mon, $mday, $hour, $min, $sec;
+    my $date_time = DateTime->new(
+      year       => $year,
+      month      => $mon,
+      day        => $mday,
+    );
+    my $month_name  = $date_time->month_name;
+    my $month_abbr  = $date_time->month_abbr;
+    my $day_name    = $date_time->day_name;
+    my $day_abbr    = $date_time->day_abbr;
+
+    my $build = {};
+      $build->{date} = $now_date;
+      $build->{year} = sprintf "%04d", $year;
+      $build->{month} = sprintf "%02d", $mon;
+      $build->{month_name} = $month_name;
+      $build->{month_abbr} = $month_abbr;
+      $build->{day} = sprintf "%02d", $mday;
+      $build->{day_name} = $day_name;
+      $build->{day_abbr} = $day_abbr;
+      $build->{hour} = sprintf "%02d", $hour;
+      $build->{minute} = sprintf "%02d", $min;
+      $build->{second} = sprintf "%02d", $sec;
+
+
+
     ######################
     use Mira::View;
 
@@ -157,10 +188,6 @@ sub execute {
     $diff = Time::HiRes::tv_interval($start_time);
     print "start main: $diff\n";
 
-    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
-    $year += 1900;
-    $mon += 1;
-    my $now_date = sprintf "%04d-%02d-%02d %02d:%02d:%02d", $year, $mon, $mday, $hour, $min, $sec;
 
     Mira::View::Main->template(
       config => $config,
@@ -169,7 +196,7 @@ sub execute {
       floors => $floors_base,
       pensource => $source,
       floor_data => $floor_data,
-      date => $now_date,
+      build => $build,
     );
 
     $diff = Time::HiRes::tv_interval($start_time);
@@ -183,7 +210,7 @@ sub execute {
       pensource => $source,
       lists => $lists_data,
       floor_data => $floor_data,
-      date => $now_date,
+      build => $build,
     );
 
     Mira::View::Feed->template(
@@ -194,7 +221,7 @@ sub execute {
       pensource => $source,
       lists => $lists_data,
       floor_data => $floor_data,
-      date => $now_date,
+      build => $build,
     );
 
     $diff = Time::HiRes::tv_interval($start_time);
@@ -208,7 +235,7 @@ sub execute {
       pensource => $source,
       lists => $lists_data,
       floor_data => $floor_data,
-      date => $now_date,
+      build => $build,
     );
 
     $diff = Time::HiRes::tv_interval($start_time);
@@ -222,7 +249,7 @@ sub execute {
       pensource => $source,
       lists => $lists_data,
       floor_data => $floor_data,
-      date => $now_date,
+      build => $build,
     );
 
     print "The program ran for ", time() - $^T, " seconds\n";
