@@ -21,7 +21,7 @@ sub template {
   my $pensource = $switches{pensource};
   my $lists = $switches{lists};
   my $floor_data = $switches{floor_data};
-  my $now_date = $switches{date};
+  my $build = $switches{build};
 
 
   foreach my $utid (keys %$allentries)
@@ -88,6 +88,7 @@ sub template {
       Archives => $lists->{$floor},
       MAIN => $config->{_default},
       SITE => $config->{$floor},
+      BUILD => $build,
       FarsiNum => bless(\&farsinum, 'mira'),
     };
 
@@ -97,8 +98,6 @@ sub template {
       return $string;
     }
 
-    $vars->{DATE} = $now_date;
-
     $vars->{MainURL} =~ s"(?<!http:)/+"/"g;
     $vars->{MainURL} =~ s"/$""g;
 
